(function( $ ) {
    'use strict';

    // Create the defaults once
    var pluginName = "wordpress_multilingual_multisite",
        defaults = {
            bla: "",
        };

    // The actual plugin constructor
    function Plugin ( element, options ) {
        this.element = element;
        this.settings = $.extend( {}, defaults, options );
        this._defaults = defaults;

        this._name = pluginName;
        this.init();
    }

    // Avoid Plugin.prototype conflicts
    $.extend( Plugin.prototype, {
        init: function() {
            var that = this;
            this.window = $(window);
            this.documentHeight = $( document ).height();
            this.windowHeight = this.window.height();
            this.privacySettingsCheckPerformed = false;

            this.elements = {};

            // this.checkFontAwesomeloaded = setInterval(function(){
            //     that.animateFontAwesome();
            // }, 200);
            if (jQuery.fn.select2) {
                that.select2();
            }
        },
        animateFontAwesome : function() {

            if($('html').hasClass('fontawesome-i2svg-complete')) {

                clearInterval(this.checkFontAwesomeloaded);
                $('.font-animate').fontAnimate(
                {
                    stroke: '#0073aa',
                    // fill: '#0073aa',
                    strokeWidth : 20,
                    duration: 500 // Vivus specific animation option
                  }
                  );
            }
            // console.log(this.elements.icons);
            // this.elements.icons.fontAnimate();
        },
        select2 : function() {

            var field = $('.wordpress-multilingual-multisite-input-field');
            if(field.length > 0) {

                if(field.hasClass('wordpress-multilingual-multisite-translated-posts-select')) {
                    field.select2({
                        placeholder :'Select item ...',
                        ajax: {
                        method: "POST",
                        dataType: 'json',
                        delay: 250, // wait 250 milliseconds before triggering the request
                        url: ajaxurl,
                        minimumInputLength: 1,
                        data: function (params) {
                          var query = {
                            search: params.term,
                            action: 'wordpress_multilingual_multisite_get_network_posts',
                            blog_id : $(this).data('blog-id'),
                            post_type : $(this).data('post-type'),
                          }

                          // Query parameters will be ?search=[term]&type=public
                          return query;
                        },
                        processResults: function (data) {
                            return {
                                results: $.map(data.items, function (item) {
                                    return {
                                        text: item.text,
                                        id: item.id
                                    }
                                })
                            };
                        }
                      }
                    }).trigger('change');

                } else {
                    field.select2( {
                         placeholder :'Select item ...',
                    });
                }

                // $('.wordpress-multilingual-multisite-translated-posts-select').on('select2:')
            }
        },
        //////////////////////
        ///Helper Functions///
        //////////////////////
        deleteAllCookies : function() {
            var cookies = document.cookie.split(";");
            console.log(cookies);
            for (var i = 0; i < cookies.length; i++) {
                var cookie = cookies[i];
                var eqPos = cookie.indexOf("=");
                var name = eqPos > -1 ? cookie.substr(0, eqPos) : cookie;
                document.cookie = name + "=;expires=Thu, 01 Jan 1970 00:00:00 GMT";
            }

        },
        isEmpty: function(obj) {

            if (obj == null)        return true;
            if (obj.length > 0)     return false;
            if (obj.length === 0)   return true;

            for (var key in obj) {
                if (hasOwnProperty.call(obj, key)) return false;
            }

            return true;
        },
        sprintf: function parse(str) {
            var args = [].slice.call(arguments, 1),
                i = 0;

            return str.replace(/%s/g, function() {
                return args[i++];

            });
        },
        getCookie: function(cname) {
            var name = cname + "=";
            var ca = document.cookie.split(';');
            for(var i=0; i<ca.length; i++) {
                var c = ca[i];
                while (c.charAt(0)==' ') c = c.substring(1);
                if (c.indexOf(name) === 0) return c.substring(name.length, c.length);
            }
            return "";
        },
        createCookie: function(name, value, days) {
            var expires = "";

            if (days) {
                var date = new Date();
                date.setTime(date.getTime() + (days*24*60*60*1000));
                var expires = "; expires="+date.toGMTString();
            }

            document.cookie = name + "=" + value+expires + "; path=/";
        },
        deleteCookie: function(name) {
            this.createCookie(name, '', -10);
        },
        getParameterByName: function(name, url) {
            if (!url) url = window.location.href;
            name = name.replace(/[\[\]]/g, "\\$&");
            var regex = new RegExp("[?&]" + name + "(=([^&#]*)|&|#|$)", "i"),
                results = regex.exec(url);
            if (!results) return null;
            if (!results[2]) return '';
            return decodeURIComponent(results[2].replace(/\+/g, " "));
        },
        isInArray : function (value, array) {
            return array.indexOf(value) > -1;
        }
    } );

    // Constructor wrapper
    $.fn[ pluginName ] = function( options ) {
        return this.each( function() {
            if ( !$.data( this, "plugin_" + pluginName ) ) {
                $.data( this, "plugin_" +
                    pluginName, new Plugin( this, options ) );
            }
        } );
    };

    $(document).ready(function() {

        $( "body" ).wordpress_multilingual_multisite();

    } );

})( jQuery );