<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://welaunch.io/plugins/wordpress-multilingual-multisite/
 * @since      1.0.0
 *
 * @package    WordPress_Multilingual_Multisite
 * @subpackage WordPress_Multilingual_Multisite/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    WordPress_Multilingual_Multisite
 * @subpackage WordPress_Multilingual_Multisite/admin
 * @author     Daniel Barenkamp <support@welaunch.io>
 */
class WordPress_Multilingual_Multisite_Users extends WordPress_Multilingual_Multisite {

	protected $plugin_name;
	protected $version;
	protected $current_blog_id;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version, $current_blog_id) 
	{
		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->current_blog_id = $current_blog_id;
	}

	public function init() 
	{

		global $wordpress_multilingual_multisite;
		$this->options = $wordpress_multilingual_multisite;
	}

	public function user_registered($user_id)
	{
		global $blogs_data;

		if(!$this->get_option('usersSync')) {
			return false;
		}

		if(!$user_id) {
			return false;
		}

		if(empty($blogs_data)) {
			die('empty blog data');
		}

        $user_info = get_userdata( $user_id );            
        $role = $user_info->roles;

        if ( $role != null ) {
            $role = $user_info->roles[0];
        } else {
            $role = 'subscriber';
        }

        if ( isset( $_REQUEST['role'] ) && $_REQUEST['role'] != null ) {
            $role = sanitize_text_field( $_REQUEST['role'] );
        }

        foreach ($blogs_data as $blog_id => $blog_data) {
        	add_user_to_blog( $blog_id, $user_id, $role );	
        }		
	}

	public function profile_updated($user_id, $old_user_data )
	{

	}

	public function test($results, $args )
	{
		if(!is_account_page()) {
			return $results;
		}

		global $blogs_data;
		if(empty($blogs_data)) {
			return $results;
		}

		$temp = array();
		foreach ($blogs_data as $blog_id => $blog_data) {
			switch_to_blog($blog_id);
			$new = WC_Data_Store::load( 'order' )->query( $args );
			if(empty($temp) && !empty($new->orders)) {
				$temp = $new;
			} elseif(!empty($new->orders)) {
				$temp->orders = array_merge($temp->orders, $new->orders);
				$temp->total = $temp->total + $new->total;
			}

			restore_current_blog();
		}
		$results = $temp;

		return $results;

	}

}