<?php
    
    require_once plugin_dir_path( dirname( __FILE__ ) ) . 'data/languages.php';
    
    global $wp_trans_languages;
    /**
     * For full documentation, please visit: http://docs.reduxframework.com/
     * For a more extensive sample-config file, you may look at:
     * https://github.com/reduxframework/redux-framework/blob/master/sample/sample-config.php
     */

    if ( ! class_exists( 'weLaunch' ) && ! class_exists( 'Redux' ) ) {
        return;
    }

    if( class_exists( 'weLaunch' ) ) {
        $framework = new weLaunch();
    } else {
        $framework = new Redux();
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "wordpress_multilingual_multisite";

    // WP > 4.6
    if ( function_exists( 'get_sites' ) && class_exists( 'WP_Site_Query' ) ) {
        $sites = get_sites();
    // WP < 4.6
    } else {
        $sites = wp_get_sites();
    }

    $sitesSelect = array();
    foreach ($sites as $site) {
        $sitesSelect[$site->blog_id] = $site->domain . $site->path;
    }

    $args = array(
        'opt_name' => 'wordpress_multilingual_multisite',
        'use_cdn' => TRUE,
        'dev_mode' => FALSE,
        'display_name' => esc_html__('WordPress Multilingual Multisite', 'wordpress-multilingual-multisite'),
        'display_version' => '1.2.9',
        'page_title' => esc_html__('WordPress Multilingual Multisite', 'wordpress-multilingual-multisite'),
        'update_notice' => TRUE,
        'intro_text' => '',
        'footer_text' => '&copy; '.date('Y').' weLaunch',
        'admin_bar' => FALSE,
        'menu_type' => 'menu',
        'menu_title' => esc_html__('Translation', 'wordpress-multilingual-multisite'),
        'menu_icon' => 'dashicons-flag',
        'allow_sub_menu' => TRUE,
        'page_parent_post_type' => 'your_post_type',
        'customizer' => FALSE,
        'default_mark' => '*',
        'hints' => array(
            'icon_position' => 'right',
            'icon_color' => 'lightgray',
            'icon_size' => 'normal',
            'tip_style' => array(
                'color' => 'light',
            ),
            'tip_position' => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect' => array(
                'show' => array(
                    'duration' => '500',
                    'event' => 'mouseover',
                ),
                'hide' => array(
                    'duration' => '500',
                    'event' => 'mouseleave unfocus',
                ),
            ),
        ),
        'output' => TRUE,
        'output_tag' => TRUE,
        'settings_api' => TRUE,
        'cdn_check_time' => '1440',
        'compiler' => TRUE,
        'page_permissions' => 'manage_network',
        'save_defaults' => TRUE,
        'show_import_export' => TRUE,
        'transient_time' => '3600',
        'network_sites' => TRUE,
        'network_admin' => true,
        'database' => 'network',
    );

    global $weLaunchLicenses;
    if( isset($weLaunchLicenses['wordpress-multilingual-multisite']) && !empty($weLaunchLicenses['wordpress-multilingual-multisite']) ) {
        $args['display_name'] = '<span class="dashicons dashicons-yes-alt" style="color: #9CCC65 !important;"></span> ' . $args['display_name'];
    } else {
        $args['display_name'] = '<span class="dashicons dashicons-dismiss" style="color: #EF5350 !important;"></span> ' . $args['display_name'];
    }


    $framework::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'help-tab',
            'title'   => esc_html__( 'Information', 'wordpress-multilingual-multisite' ),
            'content' => esc_html__( '<p>Need support? Please use the comment function on codecanyon.</p>', 'wordpress-multilingual-multisite' )
        ),
    );
    $framework::setHelpTab( $opt_name, $tabs );


   $blacklist = array(
        'attachment',
        'revision', 
        'custom_css', 
        'nav_menu_item',
        'customize_changeset', 
        'oembed_cache', 
        'vc4_templates', 
        'vc_grid_item', 
        'shop_order_refund', 
        'shop_order', 
        'shop_coupon',
        'user_request',
        'scheduled-action',
    );

    global $wpdb;
    $post_types = array();
    $res = $wpdb->get_results("SELECT DISTINCT post_type FROM `{$wpdb->prefix}posts`", ARRAY_A);
    if(!empty($res)) {
        foreach ($res as $key => $value) {
            $post_types[$value['post_type']] = $value['post_type'];
        }

        // we try using SKU
        // if(isset($post_types['product_variation'])) {
        //     unset($post_types['product_variation']);
        // }
    }

    // Too many ...
    // $post_metas = array();
    // $res = $wpdb->get_results("SELECT DISTINCT meta_key FROM `{$wpdb->prefix}postmeta`", ARRAY_A);
    // if(!empty($res)) {
    //     foreach ($res as $key => $value) {
    //         $post_metas[$value['meta_key']] = $value['meta_key'];
    //     }
    // }

    $post_data_keys = array(
        'post_author' => 'post_author',
        'post_date' =>  'post_date',
        'post_date_gmt' =>  'post_date_gmt',
        'post_content' =>  'post_content',
        'post_title' =>  'post_title',
        'post_excerpt' =>  'post_excerpt',
        'post_status' => 'post_status',
        'comment_status' => 'comment_status',
        'ping_status' =>  'ping_status',
        'post_password' =>  'post_password',
        'post_name' => 'post_name',
        'to_ping' =>  'to_ping',
        'pinged' =>  'pinged',
        'post_modified' =>  'post_modified',
        'post_modified_gmt' => 'post_modified_gmt',
        'post_content_filtered' =>  'post_content_filtered',
        'post_parent' =>  'post_parent',
        'guid' =>  'guid',
        'menu_order' => 'menu_order',
        'post_type' => 'post_type',
        'post_mime_type' =>  'post_mime_type',
        'comment_count' => 'comment_count',
        'filter' => 'filter',
    );

    $term_data_keys = array(
        'name' => 'name',
        'slug' => 'slug',
        'term_group' =>  'term_group',
        'term_taxonomy_id' => 'term_taxonomy_id',
        'taxonomy' => 'taxonomy',
        'description' => 'description',
        'parent' => 'parent',
        'count' =>  'count',
        'filter' => 'filter',
    );

    $post_types = array_diff($post_types, $blacklist);

    $post_type_copier_options = array();
    $post_type_sync_options = array();
    foreach ($post_types as $post_type) {

        $post_type_name = ucfirst($post_type);

        // Sync Settings
        $post_type_sync_options[] = array(
            'id'       => 'syncEnable' . $post_type,
            'type'     => 'switch',
            'title'    => esc_html__( 'Enable ' . $post_type_name . ' Sync', 'wordpress-multilingual-multisite' ),
            'default' => 0,
            'required' => array('syncEnable','equals','1'),
        );
        $post_type_sync_options[] = array(
            'id'       => 'syncCreate' . $post_type,
            'type'     => 'checkbox',
            'title'    => esc_html__( 'Create ' . $post_type . ' if not exists in all languages.' , 'wordpress-multilingual-multisite' ),
            'subtitle' => __('Note: This will use the post copier settings.', 'wordpress-multilingual-multisite'),
            'default' => 0,
            'required' => array('syncEnable' . $post_type,'equals','1'),
        );
        $post_type_sync_options[] = array(
            'id'       => 'syncDelete' . $post_type,
            'type'     => 'checkbox',
            'title'    => esc_html__( 'Delete / Trash ' . $post_type . ' in all languages.' , 'wordpress-multilingual-multisite' ),
            'subtitle' => __('Delete connected ' . $post_type . ' types in all country / language sites.', 'wordpress-multilingual-multisite'),
            'default' => 0,
            'required' => array('syncEnable' . $post_type,'equals','1'),
        );
        $post_type_sync_options[] = array(
            'id'       => 'syncPostDataAll' . $post_type,
            'type'     => 'checkbox',
            'title'    => esc_html__( 'Sync All ' . $post_type . ' Data.' , 'wordpress-multilingual-multisite' ),
            'subtitle' => __('Sync connected ' . $post_type . ' types post data.', 'wordpress-multilingual-multisite'),
            'default' => 1,
            'required' => array('syncEnable' . $post_type,'equals','1'),
        );
        $post_type_sync_options[] = array(
            'id'     =>'syncPostData' . $post_type,
            'type'  => 'select',
            'multi' => true,
            'options' => $post_data_keys,
            'title' => esc_html__( 'Sync Specific ' . $post_type . ' Data Keys', 'wordpress-multilingual-multisite'), 
            'subtitle' => esc_html__('Insert your post data keys here to get synced. If empty nothing will be synced.', 'wordpress-multilingual-multisite'),
            'required' => array( array('syncEnable' . $post_type,'equals','1'), array('syncPostDataAll' . $post_type,'equals','0') ),
        );
        $post_type_sync_options[] = array(
            'id'       => 'syncPostMetaAll' . $post_type,
            'type'     => 'checkbox',
            'title'    => esc_html__( 'Sync All ' . $post_type . ' Meta.' , 'wordpress-multilingual-multisite' ),
            'subtitle' => __('Sync all ' . $post_type . ' post metas.', 'wordpress-multilingual-multisite'),
            'default' => 1,
            'required' => array('syncEnable' . $post_type,'equals','1'),
        );
        $post_type_sync_options[] = array(
            'id'     =>'syncPostMeta' . $post_type,
            'type'  => 'text',
            'title' => esc_html__('Sync Specific ' . ' ' . $post_type . ' Meta Keys', 'wordpress-multilingual-multisite'), 
            'subtitle' => esc_html__('Insert your post meta keys here (seperate by comma) to get synced. _my_custom_field', 'wordpress-multilingual-multisite'),
            'required' => array( array('syncEnable' . $post_type,'equals','1'), array('syncPostMetaAll' . $post_type,'equals','0') ),
        );
        $post_type_sync_options[] = array(
            'id'       => 'syncTerms' . $post_type,
            'type'     => 'checkbox',
            'title'    => esc_html__( 'Sync All ' . $post_type . ' Terms.' , 'wordpress-multilingual-multisite' ),
            'subtitle' => __('Sync all ' . $post_type . ' types terms.', 'wordpress-multilingual-multisite'),
            'default' => 1,
            'required' => array('syncEnable' . $post_type,'equals','1'),
        );
        $post_type_sync_options[] = array(
            'id'       => 'syncImages' . $post_type,
            'type'     => 'checkbox',
            'title'    => esc_html__( 'Sync ' . $post_type . ' Images.' , 'wordpress-multilingual-multisite' ),
            'subtitle' => __('Sync all images of ' . $post_type . '.', 'wordpress-multilingual-multisite'),
            'default' => 1,
            'required' => array('syncEnable' . $post_type,'equals','1'),
        );
    }


    $framework::setSection( $opt_name, array(
        'title'  => esc_html__( 'WordPress Multilingual Multisite', 'wordpress-multilingual-multisite' ),
        'id'     => 'general',
        'desc'   => esc_html__( 'Need support? Please use the comment function on codecanyon.', 'wordpress-multilingual-multisite' ),
        'icon'   => 'el el-home',
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'General', 'wordpress-multilingual-multisite' ),
        'desc'       => __( 'To get auto updates please <a href="' . admin_url('tools.php?page=welaunch-framework') . '">register your License here</a>.', 'woocommerce-multilingual-multisite' ),
        'id'         => 'general-settings',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'enable',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'Enable WordPress Multilingual Multisite to use the options below.', 'wordpress-multilingual-multisite' ),
                'default' => 1,
            ),
            array(
                'id'       => 'excludedSites',
                'type'     => 'select',
                'options'  => $sitesSelect,
                'title'    => esc_html__( 'Exclude Sites', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'E.g. test / dev sites can be excluded here.', 'wordpress-multilingual-multisite'),
                'multi' => true,
            ),
            array(
                'id'       => 'showConnectedItemsInOverview',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Show Connected Items in Overview', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'Enable this to show connected posts or terms in the post overview. Disable this to save performance.', 'wordpress-multilingual-multisite'),
                'default' => 1,
            ),
            
            array(
                'id'   => 'info_normal',
                'type' => 'info',
                'desc' => 
                __('<div style="text-align:center;">
                        <p>Clicking the button below will initially fill the translation tables. Click this when you installed our plugin in an existing WordPress Multisite.</p>

                        <a href="' . get_admin_url() . 'admin.php?page=wordpress_multilingual_multisite_options&init-translation-tables=true" class="button button-success">INIT Translation Tables</a>

                        <p>To setup the language & country section of each site, please go to the bottom <a href="' . get_admin_url() . 'options-general.php">general settings</a> of each site.</p>
                </div>', 'redux-framework-demo')
            )
        )
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Country Selector', 'wordpress-multilingual-multisite' ),
        'desc'       => __( 'Use on of the following shortcodes OR enable to show the country selector in your menu below: <br>
                            Country Selector: [wordpress_multilingual_multisite_country_selector]<br>
                            Country Selector Page: [wordpress_multilingual_multisite_country_selector_page]<br>
                            <br>
                            Make sure you set country & language settings correctly in Settings > General (bottom).', 'wordpress-multilingual-multisite' ),
        'id'         => 'country-selector',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'countrySelectorShowCurrentFlag',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Show Current Flag', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'Shows the flag of the site the user is on.', 'wordpress-multilingual-multisite'),
                'default' => 1,
            ),
            array(
                'id'       => 'countrySelectorShowCaret',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Show caret icon', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'Show Default other country URLs in the dropdown when no Linked Posts found.', 'wordpress-multilingual-multisite'),
                'default' => 0,
            ),
            array(
                'id'       => 'countrySelectorShowWhenNotLinked',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Show Default URL', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'Show Default other country URLs in the dropdown when no Linked Posts found.', 'wordpress-multilingual-multisite'),
                'default' => 1,
            ),
            array(
                'id'       => 'countrySelectorMenuEnable',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Enable Country Selector in Menu', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'Add the country selector to a specific menu item automatically.', 'wordpress-multilingual-multisite'),
                'default' => 1,
            ),
            array(
                'id'       => 'countrySelectorProductSKUFallback',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'SKU Fallback', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'Fallback for WooCommerce by product SKUs.', 'wordpress-multilingual-multisite'),
                'default' => 1,
            ),
            array(
                'id'       => 'countrySelectorMenuThemeLocation',
                'type'     => 'text',
                'title'    => esc_html__( 'Menu Display Position', 'wordpress-multilingual-multisite' ),
                'subtitle' => __( 'Set the display position name here e.g. primary or main. <a href="https://www.welaunch.io/en/knowledge-base/faq/get-wordpress-menu-name/" target="_blank">Learn here how to get the menu name</a>. For multiple menus comma separate the menus (no spaced between commas).', 'wordpress-multilingual-multisite'),
                'required' => array('countrySelectorMenuEnable','equals',1),
            ),
            array(
                'id'       => 'countrySelectorText',
                'type'     => 'text',
                'title'    => esc_html__( 'Country Selector Text', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'Text that appears after the flag. You can use {{language}} or {{country}} or {{blog_name}} variables here.', 'wordpress-multilingual-multisite'),
                'default'  => '{{language}} ({{country}})',
            ),
            array(
                'id'       => 'countrySelectorDropdownText',
                'type'     => 'text',
                'title'    => esc_html__( 'Country Selector Dropdown Text', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'Text that appears for each item in the dropdown. You can use {{language}} or {{country}} or {{blog_name}} variables here.', 'wordpress-multilingual-multisite'),
                'default'  => '{{language}} ({{country}})',
            ),
        )
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Master & Redirects', 'wordpress-multilingual-multisite' ),
        'desc'       => esc_html__( 'The master site can inherit options, that are saved in the wp_options table.', 'wordpress-multilingual-multisite' ),
        'id'         => 'master',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'masterSite',
                'type'     => 'select',
                'options'  => $sitesSelect,
                'title'    => esc_html__( 'Set your Master Site', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'Your Master Site can be used to set the source data for all other blogs', 'wordpress-multilingual-multisite'),
                'multi' => false,
            ),
            array(
                'id'       => 'masterOverrideSettings',
                'type'     => 'text',
                'title'    => esc_html__( 'Override Blog Settings', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'Insert blog option or theme option names here (seperate by comma), that will get overriden by master sites option. For example a plugin option name like lyte_yt_api_key to only set the api key in master site. get_option & get_theme_mod filter.', 'wordpress-multilingual-multisite'),
                'required' => array('masterSite','not',''),
            ),
            array(
                'id'       => 'masterAutomaticRedirect',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Enable Automatic Redirect', 'wordpress-multilingual-multisite' ),
                'subtitle'    => esc_html__( 'Automatically Redirect users from your master site to correct language & country subsite. E.g. DE User to /de/ site. Make sure the main site is NEVER cached!.', 'wordpress-multilingual-multisite' ),
                'default' => 1,
            ),
                array(
                    'id'       => 'masterAutomaticRedirectShortLinks',
                    'type'     => 'checkbox',
                    'title'    => esc_html__( 'Enable Automatic Short Link Redirect', 'wordpress-multilingual-multisite' ),
                    'subtitle'    => esc_html__( 'When you create posts or pages on your master site and link them to existing posts in other languages our plugin redirects to correct translated posts. An example: domain.com/awesome-content would redirect to domain.com/de/awesome-content or domain.com/en/awesome-content/. This also works for terms (categories & tags).', 'wordpress-multilingual-multisite' ),
                    'default' => 1,
                ),
                array(
                    'id'       => 'masterAutomaticRedirectIP',
                    'type'     => 'checkbox',
                    'title'    => __( 'IP Based redirect', 'wordpress-country-selector' ),
                    'subtitle' => __( 'Will use get.geojs.io lookup service (see below). You may consider GDPR.', 'wordpress-multilingual-multisite' ),
                    'default'  => '0',
                    'required' => array('masterAutomaticRedirect','equals','1'),
                ),
                    array(
                        'id'       => 'masterAutomaticRedirectIPCountryFirst',
                        'type'     => 'checkbox',
                        'title'    => __( 'Check Country before Language', 'wordpress-country-selector' ),
                        'subtitle' => __( 'Will use users country first and then language instead of language first (e.g. CH user will get redirected to CH website in German even when his language is French. Otherwise CH user gets redirected to FR site cause his language is FR.) Only works with IP because browser lang preferences do not contain country. Only use when you have no sites for countries with multiple languages like CH, CA or BE (mixed languages spoken).', 'wordpress-multilingual-multisite' ),
                        'default'  => '0',
                        'required' => array('masterAutomaticRedirectIP','equals','1'),
                    ),
                    // array(
                    //     'id'       => 'masterAutomaticRedirectIPAPIKey',
                    //     'type'     => 'text',
                    //     'title'    => __('IP Service API Key', 'wordpress-multilingual-multisite'),
                    //     'subtitle' => __('By default 10.000 request are free each month, but when you exceed this limit you need to purchase a valid license key from <a href="https://extreme-ip-lookup.com/" target="_blank">Extreme IP lookup</a>.', 'wordpress-multilingual-multisite'),
                    //     'default'  => '',
                    //     'required' => array('masterAutomaticRedirectIP','equals','1'),
                    // ),


            array(
                'id'       => 'masterDefaultRedirect',
                'type'     => 'select',
                'options'  => $sitesSelect,
                'title'    => esc_html__( 'Default Redirect Site', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'If no language version found, redirect to this site (should be EN one).', 'wordpress-multilingual-multisite'),
                'multi' => false,
            ),
        )
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Machine Translation', 'wordpress-multilingual-multisite' ),
        'desc'       => esc_html__( 'Posts and terms can be translated via machine translation services. Choose a service below, go to a post / term and translate data right away.', 'wordpress-multilingual-multisite' ),
        'id'         => 'machine-translation',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'machineEnable',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Machine Translation', 'wordpress-multilingual-multisite' ),
                'default' => 0,
            ),
            array(
                'id'       => 'defaultSourceLanguage',
                'type'     => 'select',
                'title'    => esc_html__( 'Default Source Language', 'wordpress-multilingual-multisite' ),
                'options'  => $wp_trans_languages,
                'default' => 'en',
                'required' => array('machineEnable','equals','1'),
            ),
            array(
                'id'       => 'machineServiceProvider',
                'type'     => 'select',
                'title'    => esc_html__( 'Service Provider (API)', 'wordpress-multilingual-multisite' ),
                'options'  => array(
                    'Google' => esc_html__('Google Translate (Paid)', 'wordpress-multilingual-multisite'),
                    'DeepL' => esc_html__('DeepL', 'wordpress-multilingual-multisite'),
                    'Microsoft' => esc_html__('Microsoft Translator Text API', 'wordpress-multilingual-multisite'),
                ),
                'default' => 'DeepL',
                'required' => array('machineEnable','equals','1'),
            ),
                // DeepL
                array(
                    'id'     =>'machineDeepLAPIKey',
                    'type'  => 'text',
                    'title' => esc_html__('DeepL API Key', 'wordpress-multilingual-multisite'), 
                    'required' => array('machineServiceProvider','equals','DeepL'),
                ),
                array(
                    'id'       => 'machineDeepLFree',
                    'type'     => 'checkbox',
                    'title'    => esc_html__( 'DeepL Free Version', 'wordpress-multilingual-multisite' ),
                    'default' => 0,
                    'required' => array('machineServiceProvider','equals','DeepL'),
                ),

            array(
                'id'     =>'machineGoogleAPIKey',
                'type'  => 'text',
                'title' => esc_html__('Google API Key', 'wordpress-multilingual-multisite'), 
                'required' => array('machineServiceProvider','equals','Google'),
            ),
            array(
                'id'     =>'machineMicrosoftAPIKey',
                'type'  => 'text',
                'title' => esc_html__('Microsoft API Key', 'wordpress-multilingual-multisite'), 
                'subtitle' => esc_html__('You must have a Cognitive Services API account with Microsoft Translator Text API. You will need a paid subscription key from your Azure dashboard.', 'wordpress-multilingual-multisite'),
                'required' => array('machineServiceProvider','equals','Microsoft'),
            ),
            array(
                'id'     =>'machinePostData',
                'type'  => 'select',
                'multi' => true,
                'options' => $post_data_keys,
                'title' => esc_html__('Post Data Keys', 'wordpress-multilingual-multisite'), 
                'subtitle' => esc_html__('Insert your post data keys here to get translated.', 'wordpress-multilingual-multisite'),
                'default' => array('post_title', 'post_content', 'post_name', 'post_excerpt'),
                'required' => array('machineEnable','equals','1'),
            ),
            array(
                'id'     =>'machinePostMeta',
                'type'  => 'text',
                'title' => esc_html__('Post Meta Keys', 'wordpress-multilingual-multisite'), 
                'subtitle' => esc_html__('Insert your post meta keys here (seperate by comma) to get translated (e.g. my_custom_field, _elementor_data)', 'wordpress-multilingual-multisite'),
                'default' => '_yoast_wpseo_title,_yoast_wpseo_metadesc,_elementor_data',
                'required' => array('machineEnable','equals','1'),
            ),
            array(
                'id'     =>'machineTermData',
                'type'  => 'select',
                'multi' => true,
                'options' => $term_data_keys,
                'title' => esc_html__('Term Data Keys', 'wordpress-multilingual-multisite'), 
                'subtitle' => esc_html__('Insert your term data keys here to get translated.', 'wordpress-multilingual-multisite'),
                'default' => array('name', 'slug', 'description'),
                'required' => array('machineEnable','equals','1'),
            ),
            array(
                'id'     =>'machineTermMeta',
                'type'  => 'text',
                'title' => esc_html__('Term Meta Keys', 'wordpress-multilingual-multisite'), 
                'subtitle' => esc_html__('Insert your post meta keys here (seperate by comma) to get translated. _my_custom_field', 'wordpress-multilingual-multisite'),
                'default' => 'wpseo_title,wpseo_desc',
                'required' => array('machineEnable','equals','1'),
            ),
            array(
                'id'       => 'machineSegmentData',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Segement Data', 'wordpress-multilingual-multisite' ),
                'subtitle'    => esc_html__( 'Segement post_content and term description data. Each tag value will be translated individuelly to not break HTML.', 'wordpress-multilingual-multisite' ),
                'default' => 1,
                'required' => array('machineEnable','equals','1'),
            ),
                array(
                    'id'     =>'machinePreservedKeys',
                    'type'  => 'text',
                    'title' => esc_html__('Preserved HTML Keys', 'wordpress-multilingual-multisite'), 
                    'subtitle' => esc_html__('To translate in context our plugin removes all HTML Tags. Set preserved keys here. These will be kept and NOT removed: <img><ol><ul><li><p><h1><h2><h3><h4><h5><h6><span><table><tr><td><thead><tbody><tfoot><th><figure><figcaption><blockquote><em><cite><iframe>', 'wordpress-multilingual-multisite'),
                    'default' => '<img><ol><ul><li><p><h1><h2><h3><h4><h5><h6><span><table><tr><td><thead><tbody><tfoot><th><figure><figcaption><blockquote><em><cite><iframe>',
                    'required' => array('machineSegmentData','equals','1'),
                ),
                array(
                    'id'       => 'machineAvoidAutoParagraph',
                    'type'     => 'checkbox',
                    'title'    => esc_html__( 'No Auto Paragraphs', 'wordpress-multilingual-multisite' ),
                    'subtitle'    => esc_html__( 'Do not execute wpautop on post_content (e.g. for kadence blocks)', 'wordpress-multilingual-multisite' ),
                    'default' => 0,
                    'required' => array('machineSegmentData','equals','1'),
                ),
                

            array(
                'id'       => 'machineGutenberg',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Gutenberg Support', 'wordpress-multilingual-multisite' ),
                'subtitle'    => esc_html__( 'Gutenberg support!', 'wordpress-multilingual-multisite' ),
                'default' => 1,
                'required' => array('machineEnable','equals','1'),
            ),
            array(
                'id'       => 'machineDiviSupport',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Support Divi', 'wordpress-multilingual-multisite' ),
                'subtitle'    => esc_html__( 'Divi Page Builder support. Disablet this when using Gutenberg!', 'wordpress-multilingual-multisite' ),
                'default' => 0,
                'required' => array('machineEnable','equals','1'),
            ),
            array(
                'id'       => 'machineDebugMode',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Debug Mode', 'wordpress-multilingual-multisite' ),
                'subtitle'    => esc_html__( 'Enable this when the machine translation is not working to get API call response.', 'wordpress-multilingual-multisite' ),
                'default' => 0,
                'required' => array('machineEnable','equals','1'),
            ),
            
        )
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Media', 'wordpress-multilingual-multisite' ),
        'desc'       => esc_html__( 'You can enable to sync media attachments through your sites.', 'wordpress-multilingual-multisite' ),
        'id'         => 'media',
        'subsection' => true,
        'fields'     => array(
           array(
                'id'       => 'mediaEnable',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Media Syncing', 'wordpress-multilingual-multisite' ),
                'default' => 0,
            ),
            array(
                'id'     =>'mediaMetaBlacklistKeys',
                'type'  => 'text',
                'title' => esc_html__('Media Meta Blacklist', 'wordpress-multilingual-multisite'), 
                'subtitle' => esc_html__('Insert your media meta keys here (seperate by comma), that should not get synced. E.g. _wp_attachment_image_alt to not sync the alt tag so you can translate it.', 'wordpress-multilingual-multisite'),
                'required' => array('mediaEnable','equals','1'),
                'default' => '_wp_attachment_image_alt',
            ),
            array(
                'id'       => 'wpAllImportSupport',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'WP All Import Support', 'wordpress-multilingual-multisite' ),
                'subtitle'    => esc_html__( 'Enable with caution. This will slow down imports.', 'wordpress-multilingual-multisite' ),
                'default' => 0,
                'required' => array('mediaEnable','equals','1'),
            ),
            
        )
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Post Copier', 'wordpress-multilingual-multisite' ),
        'desc'       => esc_html__( 'Copy posts from one site to another within one click on the flag either in the overview or in each post.', 'wordpress-multilingual-multisite' ),
        'id'         => 'post-copier',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'postCopierEnable',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Post Copier', 'wordpress-multilingual-multisite' ),
                'default' => 1,
            ),
            array(
                'id'       => 'postCopierCopyTerms',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Copy Terms', 'wordpress-multilingual-multisite' ),
                'default' => 1,
                'required' => array('postCopierEnable','equals','1'),
            ),
            array(
                'id'       => 'postCopierCopyImages',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Copy Images', 'wordpress-multilingual-multisite' ),
                'default' => 1,
                'required' => array('postCopierEnable','equals','1'),
            ),
            array(
                'id'     =>'postCopierExcludeDataKeys',
                'type'  => 'select',
                'multi' => true,
                'options' => $post_data_keys,
                'title' => esc_html__('Exclude Post Data Keys', 'wordpress-multilingual-multisite'), 
                'subtitle' => esc_html__('Exclude Post Data Keys from being copied.', 'wordpress-multilingual-multisite'),
                'required' => array('postCopierEnable','equals','1'),
            ),
            array(
                'id'     =>'postCopierExcludeMetaKeys',
                'type'  => 'text',
                'title' => esc_html__('Exclude Post Meta Keys', 'wordpress-multilingual-multisite'), 
                'subtitle' => esc_html__('Exclude Post Meta Keys from being copied (seperate by Comma).', 'wordpress-multilingual-multisite'),
                'required' => array('postCopierEnable','equals','1'),
            ),
            // array(
            //     'id'       => 'postCopierCopyProductAttributes',
            //     'type'     => 'checkbox',
            //     'title'    => esc_html__( 'Copy Product Attributes', 'wordpress-multilingual-multisite' ),
            //     'default' => 1,
            //     'required' => array('postCopierEnable','equals','1'),
            // ),
        )
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Term Copier', 'wordpress-multilingual-multisite' ),
        'desc'       => esc_html__( 'Copy terms from one site to another within one click on the flag either in the overview or in each term.', 'wordpress-multilingual-multisite' ),
        'id'         => 'term-copier',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'termCopierEnable',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Term Copier', 'wordpress-multilingual-multisite' ),
                'default' => 1,
            ),
            array(
                'id'     =>'termCopierExcludeDataKeys',
                'type'  => 'select',
                'multi' => true,
                'options' => $term_data_keys,
                'title' => esc_html__('Exclude Term Data Keys', 'wordpress-multilingual-multisite'), 
                'subtitle' => esc_html__('Exclude Term Data Keys from being copied.', 'wordpress-multilingual-multisite'),
                'required' => array('termCopierEnable','equals','1'),
            ),
            array(
                'id'     =>'termCopierExcludeMetaKeys',
                'type'  => 'text',
                'title' => esc_html__('Exclude Term Meta Keys', 'wordpress-multilingual-multisite'), 
                'subtitle' => esc_html__('Exclude Term Meta Keys from being copied (seperate by Comma).', 'wordpress-multilingual-multisite'),
                'required' => array('termCopierEnable','equals','1'),
            ),
        )
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Post Im- / Export', 'wordpress-multilingual-multisite' ),
        'desc'       => esc_html__( 'Posts can be exported as XML or JSON, translated by any 3rd party vendor and reimported again. Add the following constant to your wp-config in order to upload json / xml files: define(\'ALLOW_UNFILTERED_UPLOADS\', true);', 'wordpress-multilingual-multisite' ),
        'id'         => 'post-im-export',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'     =>'postImportExportEnable',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Post Export / Import', 'wordpress-multilingual-multisite' ),
                'subtitle' => 'If enabled you can export post data as XML or JSON, that you can provide to your translators. 
                                    <a href="' . admin_url('admin.php?page=wordpress-multilingual-multisite-importer') . '">To import posts see here</a>.
                                    <a href="' . admin_url('admin.php?page=wordpress-multilingual-multisite-exporter') . '">To export posts see here</a>. You can also export a post when you edit it.', 'wordpress-multilingual-multisite',
                'default' => 0,
            ),
            array(
                'id'       => 'postImportExportFormat',
                'type'     => 'select',
                'title'    => esc_html__( 'Data Format', 'wordpress-multilingual-multisite' ),
                'options'  => array(
                    'xml' => esc_html__('XML', 'wordpress-multilingual-multisite'),
                    'json' => esc_html__('JSON', 'wordpress-multilingual-multisite'),
                ),
                'default' => 'json',
                'required' => array('postImportExportEnable','equals','1'),
            ),
        )
    ) ); 

    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Sync', 'wordpress-multilingual-multisite' ),
        'desc'       => esc_html__( 'Synchonize post data from posts, that are assigned to other languages.', 'wordpress-multilingual-multisite' ),
        'id'         => 'sync',
        'subsection' => true,
        'fields'     => array_merge(array(
            array(
                'id'       => 'syncEnable',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Sync', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'If enabled you can sync custom post metas & data every time when a post gets updated on any site.', 'wordpress-multilingual-multisite' ),
                'default' => 0,
            ),
            array(
                'id'       => 'syncOnlyMaster',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Only Sync Master', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'If enabled data below will only synced when a post on the master site is updated.', 'wordpress-multilingual-multisite' ),
                'default' => 0,
                'required' => array('syncEnable','equals','1'),
            ),
            array(
                'id'       => 'syncOnlySpecificPosts',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Only Sync Specific Posts', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'When enabled a checkbox will be added to all posts when you edit them in the backed. Check this to sync this post.', 'wordpress-multilingual-multisite' ),
                'default' => 0,
                'required' => array('syncEnable','equals','1'),
            ),

        ), $post_type_sync_options)
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Translator', 'wordpress-multilingual-multisite' ),
        'desc'       => esc_html__( 'Translators can be created as new users with role translator. They need to be assigned to a site first and can then be assigned to posts, that they should translate.', 'wordpress-multilingual-multisite' ),
        'id'         => 'translator',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'translatorEnable',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable translator', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'If enabled a post meta box appears, where you can select a translator for a post.', 'wordpress-multilingual-multisite' ),
                'default' => 0,
            ),
            array(
                'id'       => 'translatorRevision',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Set posts to revision', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'Posts that are updated by translators are set to revision so you can approve them before publishing.', 'wordpress-multilingual-multisite' ),
                'default' => 1,
                'required' => array('translatorEnable','equals','1'),
            ),
            array(
                'id'       => 'translatorEmail',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Email translators', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'Send an email to translator if they get a post assigned for translation.', 'wordpress-multilingual-multisite' ),
                'default' => 1,
                'required' => array('translatorEnable','equals','1'),
            ),
        )
    ) );


    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Users', 'wordpress-multilingual-multisite' ),
        'id'         => 'user-settings',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'usersSync',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable User Syncing', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'Users will be added to all sites (except excluded ones) automatically when new registered.', 'wordpress-multilingual-multisite' ),
                'default' => 1,
            ),
            array(
                'id'       => 'usersSyncData',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Update User Data', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'Update user data automatically.', 'wordpress-multilingual-multisite' ),
                'default' => 1,
            ),
        )
    ) );

    $framework::setSection( $opt_name, array(
        'title'      => esc_html__( 'Advanced', 'wordpress-multilingual-multisite' ),
        'id'         => 'advanced-settings',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'advancedBasicAuth',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable Basic Auth', 'wordpress-multilingual-multisite' ),
                'subtitle' => esc_html__( 'If your site is behind htacces image fetching will not work without authentication.', 'wordpress-multilingual-multisite' ),
                'default' => 0,
            ),
            array(
                'id'       => 'advancedBasicAuthUser',
                'type'     => 'text',
                'title'    => esc_html__( 'Basic Auth User', 'wordpress-multilingual-multisite' ),
                'required' => array('advancedBasicAuth', 'equals', '1'),
            ),
            array(
                'id'       => 'advancedBasicAuthPassword',
                'type'     => 'text',
                'title'    => esc_html__( 'Basic Auth Password', 'wordpress-multilingual-multisite' ),
                'required' => array('advancedBasicAuth', 'equals', '1'),
            ),
            array(
                'id'       => 'imageDebug',
                'type'     => 'switch',
                'title'    => __( 'Image Debug', 'woocommerce-multisite-duplicate' ),
                'subtitle' => __( 'This will return image copy errors for debugging.', 'woocommerce-multisite-duplicate' ),
            ),
        )
    ) );

    /*
     * <--- END SECTIONS
     */