<?php

/**
 * Fired during plugin activation
 *
 * @link       https://welaunch.io/plugins/wordpress-multilingual-multisite/
 * @since      1.0.0
 *
 * @package    WordPress_Multilingual_Multisite
 * @subpackage WordPress_Multilingual_Multisite/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    WordPress_Multilingual_Multisite
 * @subpackage WordPress_Multilingual_Multisite/includes
 * @author     Daniel Barenkamp <support@welaunch.io>
 */
class WordPress_Multilingual_Multisite_Activator {

	public function __construct() 
	{
		return $this;
	}

	/**
	 * Short Description. (use period)
	 *
	 * Long Description.
	 *
	 * @since    1.0.0
	 */
	public function activate() {

		if (! is_multisite() ) {
			die('You are not on a multisite - plugin only works on Multisite Environments.');
		}

		if (! wp_next_scheduled ( 'run_wordpress_multilingual_multisite_cron' )) {
			wp_schedule_event(time(), 'hourly', 'run_wordpress_multilingual_multisite_cron');
		}

		$this->add_translator_role();
		$this->create_translations_tables();
		$this->add_blog_options();

		wp_redirect( network_admin_url('admin.php?page=wordpress_multilingual_multisite_options&init-translation-tables=true') );

	}

	public function add_translator_role()
	{
	    global $wp_roles;

	    if (!$wp_roles instanceof WP_Roles) {
	      $wp_roles = new WP_Roles;
	    }

	    $caps = array(
			'delete_others_pages' => false,
			'delete_others_posts' => false,
			'delete_pages' => false,
			'delete_posts' => false,
			'delete_private_pages' => false,
			'delete_private_posts' => false,
			'delete_published_pages' => false,
			'delete_published_posts' => false,
			'edit_others_pages' => true,
			'edit_others_posts' => true,
			'edit_pages' => true,
			'edit_posts' => true,
			'edit_private_pages' => false,
			'edit_private_posts' => false,
			'edit_published_pages' => true,
			'edit_published_posts' => true,
			'manage_categories' => false,
			'manage_links' => false,
			'moderate_comments' => false,
			'publish_pages' => false,
			'publish_posts' => false,
			'read' => true,
			'read_private_pages' => false,
			'read_private_posts' => false,
			'unfiltered_html' => false,
			'upload_files' => false,
	    );

	   	$sites = get_sites();
	   	if(empty($sites)) {
	   		return false;
	   	}

	   	foreach ($sites as $site) {
	   		switch_to_blog($site->blog_id);

	   		add_role( 'translator', esc_html__( 'Translator', 'wordpress-multilingual-multisite' ), $caps );

	   		restore_current_blog();
	   	}
	}

	public function create_translations_tables()
	{
	   	global $wpdb;

	   	$sites = get_sites();

	   	if(empty($sites)) {
	   		return false;
	   	}

	   	// auto ALTER TABLE `KlE48_terms_translations` CHANGE `type` `type` VARCHAR(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL;
	   	// check version of current plugin ...

	   	// Post Translations
	   	$db_name = $wpdb->prefix . 'posts_translations';

	   	$sql = "CREATE TABLE " . $db_name . " (
				`id` bigint(20) NOT NULL AUTO_INCREMENT,
				`type` varchar(50) COLLATE utf8_general_ci NOT NULL,
				`data` longtext COLLATE utf8_general_ci NULL,";

		$unique = '';
	   	foreach ($sites as $site) {
	   		$sql .= "`" . $site->blog_id . "` bigint(20) NULL,";
	   		$unique .= " UNIQUE KEY `blog_u_" . $site->blog_id . "` (`" . $site->blog_id . "`),";
	   	}

	   	$sql .= $unique;
	   	$sql .= " PRIMARY KEY (`id`))";
		
		require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
		dbDelta($sql);

	 	// Terms Translations
		$db_name = $wpdb->prefix . 'terms_translations';

	   	$sql = "CREATE TABLE " . $db_name . " (
				`id` bigint(20) NOT NULL AUTO_INCREMENT,
				`type` varchar(50) COLLATE utf8_general_ci NOT NULL,
				`data` longtext COLLATE utf8_general_ci NULL,";

		$unique = '';
	   	foreach ($sites as $site) {
	   		$sql .= "`" . $site->blog_id . "` bigint(20) NULL,";
	   		$unique .= " UNIQUE KEY `blog_u_" . $site->blog_id . "` (`" . $site->blog_id . "`),";
	   	}

	   	$sql .= $unique;
	   	$sql .= " PRIMARY KEY (`id`))";
		
	 	
		require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
		dbDelta($sql);
	}

	public function add_blog_options()
	{
	   	$sites = get_sites();

	   	if(empty($sites)) {
	   		return false;
	   	}

		foreach ($sites as $site) {

			$locale = "";
			$language = "";
			$country = "";

			if($site->blog_id == 1) {
				$language = 'en_UN';
			} else {
				$language = get_blog_option($site->blog_id, 'WPLANG');
			}

			if(empty($language)) {
				$language = "en_US";
			}
				
			if(strlen($language) > 5) {
				$language = substr( $language, 0, 5);
			}

			if(strlen($language) == 2) {
				$locale = $language . '_' . strtoupper($language);
				$country = strtoupper($language);
				$language = strtolower($language);
				$alternate = $language;

			} elseif(strlen($language) == 5) {
				$locale = $language;
				$country = substr( strtoupper($language), -2);
				$language = substr( strtolower($language), 0, 2);
				if($locale == "en_UN") {
					$alternate = 'x-default';
				} else {
					$alternate = str_replace('_', '-', $locale);
				}
			}

			$checkExists = get_blog_option($site->blog_id, 'we_locale');
			if(empty($checkExists)) {
				add_blog_option($site->blog_id, 'we_locale', $locale);
			}

			$checkExists = get_blog_option($site->blog_id, 'we_language');
			if(empty($checkExists)) {
				add_blog_option($site->blog_id, 'we_language', $language);
			}
			
			$checkExists = get_blog_option($site->blog_id, 'we_alternate');
			if(empty($checkExists)) {
				add_blog_option($site->blog_id, 'we_alternate', $alternate);
			}
			
			$checkExists = get_blog_option($site->blog_id, 'we_country');
			if(empty($checkExists)) {
				add_blog_option($site->blog_id, 'we_country', $country);
			}
		}
	}
}